==> zio-aws-ec2_2.12-5.17.161.1-sources.jar: zio/aws/ec2/model/DeleteVpcEndpointServiceConfigurationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteVpcEndpointServiceConfigurationsResponse(
    unsuccessful: Option[Iterable[zio.aws.ec2.model.UnsuccessfulItem]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse = {
    import DeleteVpcEndpointServiceConfigurationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
      .builder()
      .optionallyWith(
        unsuccessful.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.unsuccessful)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse.ReadOnly =
    zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
      .wrap(buildAwsValue())
}
object DeleteVpcEndpointServiceConfigurationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse =
      zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse(
        unsuccessful.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def unsuccessful: Option[List[zio.aws.ec2.model.UnsuccessfulItem.ReadOnly]]
    def getUnsuccessful: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.UnsuccessfulItem.ReadOnly
    ]] = AwsError.unwrapOptionField("unsuccessful", unsuccessful)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
  ) extends zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse.ReadOnly {
    override val unsuccessful
        : Option[List[zio.aws.ec2.model.UnsuccessfulItem.ReadOnly]] = scala
      .Option(impl.unsuccessful())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.UnsuccessfulItem.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
  ): zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.20.17.2-sources.jar: zio/aws/ec2/model/DeleteVpcEndpointServiceConfigurationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteVpcEndpointServiceConfigurationsResponse(
    unsuccessful: Optional[Iterable[zio.aws.ec2.model.UnsuccessfulItem]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse = {
    import DeleteVpcEndpointServiceConfigurationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
      .builder()
      .optionallyWith(
        unsuccessful.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.unsuccessful)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse.ReadOnly =
    zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
      .wrap(buildAwsValue())
}
object DeleteVpcEndpointServiceConfigurationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse =
      zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse(
        unsuccessful.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def unsuccessful
        : Optional[List[zio.aws.ec2.model.UnsuccessfulItem.ReadOnly]]
    def getUnsuccessful: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.UnsuccessfulItem.ReadOnly
    ]] = AwsError.unwrapOptionField("unsuccessful", unsuccessful)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
  ) extends zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse.ReadOnly {
    override val unsuccessful
        : Optional[List[zio.aws.ec2.model.UnsuccessfulItem.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.unsuccessful())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.UnsuccessfulItem.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse
  ): zio.aws.ec2.model.DeleteVpcEndpointServiceConfigurationsResponse.ReadOnly =
    new Wrapper(impl)
}
